AbtoConfig class
Constructors
- AbtoConfig({required String projectKey, String? endpoint, AbtoEnvironment environment = AbtoEnvironment.production, bool? debug, int batchSize = 20, Duration flushInterval = const Duration(seconds: 5)})
-
factory
Properties
- batchSize → int
-
final
- debug → bool
-
final
- endpoint → Uri
-
final
- environment → AbtoEnvironment
-
final
- flushInterval → Duration
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- projectKey → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited